package org.snmp4j.model.snmp.api;

import org.snmp4j.smi.OctetString;

import java.util.Arrays;

/**
 * The {@link SnmpProxyId} object represents an unique ID for {@link org.snmp4j.model.snmp.proxy.SnmpProxyObject}
 * instances. Unless MIB modules are using the same object names within their modules, the module name could be
 * <code>null</code>. The <code>null</code> or empty context name represents the default context.
 *
 * @author Frank Fock
 */
public class SnmpProxyId {
  private String moduleName;
  private String objectName;
  private Object[] indexValues;
  private OctetString contextName;

  public SnmpProxyId(OctetString contextName, String moduleName, String objectName, Object... indexValues) {
    this.contextName = contextName;
    this.moduleName = moduleName;
    this.objectName = objectName;
    this.indexValues = indexValues;
  }

  public OctetString getContextName() {
    return contextName;
  }

  public Object[] getIndexValues() {
    return indexValues;
  }

  public String getModuleName() {
    return moduleName;
  }

  public String getObjectName() {
    return objectName;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;

    SnmpProxyId that = (SnmpProxyId) o;

    if (moduleName != null ? !moduleName.equals(that.moduleName) : that.moduleName != null) return false;
    if (!objectName.equals(that.objectName)) return false;
    // Probably incorrect - comparing Object[] arrays with Arrays.equals
    if (!Arrays.equals(indexValues, that.indexValues)) return false;
    return contextName != null ? contextName.equals(that.contextName) : that.contextName == null;

  }

  @Override
  public int hashCode() {
    int result = moduleName != null ? moduleName.hashCode() : 0;
    result = 31 * result + objectName.hashCode();
    result = 31 * result + Arrays.hashCode(indexValues);
    result = 31 * result + (contextName != null ? contextName.hashCode() : 0);
    return result;
  }
}
